==> bubble-dubble-2017.10.23.tar.gz: bubble-dubble-2017.10.23/bubble/bclient/wsopts.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from PyQt5 import QtCore, QtWidgets, QtGui
from ..bcommon import default
from .fixedwidget import FixedWidget
from .ui.ui_wsopts import Ui_WSOpts


class WSOpts(QtWidgets.QDialog, Ui_WSOpts, FixedWidget):
    def __init__(self, parent):
        super().__init__(parent)
        self.values = {}
        self.setUI()
        self.on_buttonBox_accepted()

    def setUI(self):
        self.setupUi(self)
        self.spinThreads.setMaximum(default.MAX_THREADS)
        self.fixWindow()

    def loadSettings(self):
        s = QtCore.QSettings()
        self.checkThreads.setChecked(s.value('WSOpts/checkThreads', False, bool))
        self.checkBins.setChecked(s.value('WSOpts/checkBins', False, bool))
        self.checkPol.setChecked(s.value('WSOpts/checkPol', False, bool))
        self.checkDouble.setChecked(s.value('WSOpts/checkDouble', False, bool))
        self.checkHalina.setChecked(s.value('WSOpts/checkHalina', False, bool))
        self.checkSA.setChecked(s.value('WSOpts/checkSA', True, bool))
        self.spinPol.setValue(s.value('WSOpts/spinPol', 0, float))
        self.spinBins.setValue(s.value('WSOpts/spinBins', 1, int))
        self.spinThreads.setValue(s.value('WSOpts/spinThreads', 1, int))

    def saveSettings(self):
        s = QtCore.QSettings()
        s.setValue('WSOpts/checkThreads', self.checkThreads.isChecked())
        s.setValue('WSOpts/checkBins', self.checkBins.isChecked())
        s.setValue('WSOpts/checkPol', self.checkPol.isChecked())
        s.setValue('WSOpts/checkDouble', self.checkDouble.isChecked())
        s.setValue('WSOpts/checkHalina', self.checkHalina.isChecked())
        s.setValue('WSOpts/checkSA', self.checkSA.isChecked())
        s.setValue('WSOpts/spinPol', self.spinPol.value())
        s.setValue('WSOpts/spinBins', self.spinBins.value())
        s.setValue('WSOpts/spinThreads', self.spinThreads.value())

    def showEvent(self, event: QtGui.QShowEvent):
        super().showEvent(event)
        self.values = {}
        for name in self.__dict__:
            widget = self.__dict__[name]
            if isinstance(widget, QtWidgets.QAbstractSpinBox):
                self.values[name] = widget.value()
            elif isinstance(widget, QtWidgets.QCheckBox):
                self.values[name] = widget.isChecked()

    @QtCore.pyqtSlot(bool)
    def on_checkThreads_toggled(self, checked):
        self.spinThreads.setEnabled(checked)

    @QtCore.pyqtSlot(bool)
    def on_checkBins_toggled(self, checked):
        self.spinBins.setEnabled(checked)

    @QtCore.pyqtSlot(bool)
    def on_checkPol_toggled(self, checked):
        self.spinPol.setEnabled(checked)

    @QtCore.pyqtSlot()
    def on_buttonBox_accepted(self):
        self.params = {
            'polarization': self.spinPol.value() if self.checkPol.isChecked() else -2,
            'threads': self.spinThreads.value() if self.checkThreads.isChecked() else 0,
            'bins': self.spinBins.value() if self.checkBins.isChecked() else 0,
            'solidangle': self.checkSA.isChecked(),
            'halina': self.checkHalina.isChecked(),
            'double': self.checkDouble.isChecked(),
        }

    @QtCore.pyqtSlot()
    def on_buttonBox_rejected(self):
        for name in self.values:
            widget = self.__dict__[name]
            if isinstance(widget, QtWidgets.QAbstractSpinBox):
                widget.setValue(self.values[name])
            elif isinstance(widget, QtWidgets.QCheckBox):
                widget.setChecked(self.values[name])

==> bubble-dubble-2018.11.8.1.tar.gz: bubble-dubble-2018.11.8.1/bubble/bclient/wsopts.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from PyQt5 import QtCore, QtWidgets, QtGui
import qtsnbl.widgets
from ..bcommon import default
from .ui.ui_wsopts import Ui_WSOpts


class WSOpts(QtWidgets.QDialog, Ui_WSOpts, qtsnbl.widgets.FixedWidget):
    def __init__(self, parent):
        super().__init__(parent)
        self.values = {}
        self.setUI()
        self.on_buttonBox_accepted()

    def setUI(self):
        self.setupUi(self)
        self.spinThreads.setMaximum(default.MAX_THREADS)
        self.fixWindow()

    def loadSettings(self):
        s = QtCore.QSettings()
        self.checkThreads.setChecked(s.value('WSOpts/checkThreads', False, bool))
        self.checkBins.setChecked(s.value('WSOpts/checkBins', False, bool))
        self.checkABins.setChecked(s.value('WSOpts/checkABins', False, bool))
        self.checkPol.setChecked(s.value('WSOpts/checkPol', False, bool))
        self.checkChi.setChecked(s.value('WSOpts/checkChi', False, bool))
        self.checkCake.setChecked(s.value('WSOpts/checkCake', False, bool))
        self.checkDouble.setChecked(s.value('WSOpts/checkDouble', False, bool))
        self.checkHalina.setChecked(s.value('WSOpts/checkHalina', False, bool))
        self.checkSA.setChecked(s.value('WSOpts/checkSA', True, bool))
        self.spinPol.setValue(s.value('WSOpts/spinPol', 0, float))
        self.spinBins.setValue(s.value('WSOpts/spinBins', 0, int))
        self.spinABins.setValue(s.value('WSOpts/spinABins', 0, int))
        self.spinThreads.setValue(s.value('WSOpts/spinThreads', 1, int))
        self.on_buttonBox_accepted()

    def saveSettings(self):
        s = QtCore.QSettings()
        s.setValue('WSOpts/checkThreads', self.checkThreads.isChecked())
        s.setValue('WSOpts/checkBins', self.checkBins.isChecked())
        s.setValue('WSOpts/checkABins', self.checkABins.isChecked())
        s.setValue('WSOpts/checkPol', self.checkPol.isChecked())
        s.setValue('WSOpts/checkChi', self.checkChi.isChecked())
        s.setValue('WSOpts/checkCake', self.checkCake.isChecked())
        s.setValue('WSOpts/checkDouble', self.checkDouble.isChecked())
        s.setValue('WSOpts/checkHalina', self.checkHalina.isChecked())
        s.setValue('WSOpts/checkSA', self.checkSA.isChecked())
        s.setValue('WSOpts/spinPol', self.spinPol.value())
        s.setValue('WSOpts/spinBins', self.spinBins.value())
        s.setValue('WSOpts/spinABins', self.spinABins.value())
        s.setValue('WSOpts/spinThreads', self.spinThreads.value())

    def showEvent(self, event: QtGui.QShowEvent):
        super().showEvent(event)
        self.values = {}
        for name in self.__dict__:
            widget = self.__dict__[name]
            if isinstance(widget, QtWidgets.QAbstractSpinBox):
                self.values[name] = widget.value()
            elif isinstance(widget, QtWidgets.QCheckBox):
                self.values[name] = widget.isChecked()

    @QtCore.pyqtSlot(bool)
    def on_checkThreads_toggled(self, checked):
        self.spinThreads.setEnabled(checked)

    @QtCore.pyqtSlot(bool)
    def on_checkBins_toggled(self, checked):
        self.spinBins.setEnabled(checked)

    @QtCore.pyqtSlot(bool)
    def on_checkABins_toggled(self, checked):
        self.spinABins.setEnabled(checked)

    @QtCore.pyqtSlot(bool)
    def on_checkPol_toggled(self, checked):
        self.spinPol.setEnabled(checked)

    @QtCore.pyqtSlot()
    def on_buttonBox_accepted(self):
        self.params = {
            'polarization': self.spinPol.value() if self.checkPol.isChecked() else -2,
            'threads': self.spinThreads.value() if self.checkThreads.isChecked() else 0,
            'bins': self.spinBins.value() if self.checkBins.isChecked() else 0,
            'abins': self.spinABins.value() if self.checkABins.isChecked() else 0,
            'solidangle': self.checkSA.isChecked(),
            'halina': self.checkHalina.isChecked(),
            'double': self.checkDouble.isChecked(),
            'i_cake': self.checkCake.isChecked(),
            'i_azimuth': self.checkChi.isChecked(),
        }

    @QtCore.pyqtSlot()
    def on_buttonBox_rejected(self):
        for name in self.values:
            widget = self.__dict__[name]
            if isinstance(widget, QtWidgets.QAbstractSpinBox):
                widget.setValue(self.values[name])
            elif isinstance(widget, QtWidgets.QCheckBox):
                widget.setChecked(self.values[name])
